@@ -86,17 +86,20 @@ class _ProfileDialog(QtWidgets.QDialog):
 
     def sign_hook(self):
         try:
+            global popUp
             if not main_paras.signedIn():
-                global popUp
                 self.close()
                 popUp = _SignIn()
-                x,y = getMainTopLeft()
-                popUp.move(x,y)
-                popUp.show()
             else :
-                main_paras.singn_out_clear()
-                
+                main_paras.singn_out_clear()                
                 self.sign_bt.setText(self.tr('Sign In'))
+                self.close()
+                popUp = _WrongPassword()
+                popUp.setMessage(self.tr("The user has signed out"),self.tr('Done'))
+                
+            x,y = getMainTopLeft()
+            popUp.move(x,y)
+            popUp.show()
                 
         except Exception as error:
             print('sign_hook',error)
