@@ -1,4 +1,4 @@
-
+import RPi.GPIO as GPIO
 from gpiozero import Button
 from gpiozero import LED, PWMLED
 import time
@@ -10,26 +10,35 @@ sys.path.insert(0, parentdir)
 
 from define import *
 
-#    fan=LED(FAN_PWM_PIN, active_high=False, initial_value=True)
-fan=PWMLED(FAN_PWM_PIN, active_high=False, initial_value=0, frequency = 100)
+
+
+#fan=LED(FAN_PWM_PIN, active_high=False, initial_value=True)
+fan=PWMLED(FAN_PWM_PIN, active_high=False, initial_value=0, frequency = 300)
 hub_reset=LED(HUB_RST_PIN, initial_value=1)
 
 def fanTurnOn(on):
     global fan
     if on:
-        fan.value=0.5
+        fan.value=0.88
     else:
         fan.value=0
 def fanFullSpeedOn():
     global fan
     fan.value=1
+    
+    
+    
 if __name__ == "__main__":
+    print('on')
     fanTurnOn(True)
-    time.sleep(5)
+    time.sleep(10)
+    print('off')
     fanTurnOn(False)
-    time.sleep(5)
+    time.sleep(10)
+    print('on')
     fanTurnOn(True)
-    time.sleep(5)
+    time.sleep(10)
+    print('off')
     fanTurnOn(False)
 
     
